package IMuAHx_6.KQgRr5e_0.KQgRr5e_0.XnFJ5_9.Mqv2r_3;

import IMuAHx_6.KQgRr5e_0.KQgRr5e_0.XnFJ5_9.FSaI4_7.IMuAHx_6;
import java.io.File;
import java.util.ArrayList;
import java.util.List;
/* compiled from: BreakpointInfo.java */
/* loaded from: classes.dex */
public class PGPF6hQ_2 {
    public final int KQgRr5e_0;

    /* renamed from: KQgRr5e_0  reason: collision with other field name */
    public final IMuAHx_6.KQgRr5e_0 f148KQgRr5e_0;

    /* renamed from: KQgRr5e_0  reason: collision with other field name */
    public final File f149KQgRr5e_0;

    /* renamed from: KQgRr5e_0  reason: collision with other field name */
    public final String f150KQgRr5e_0;

    /* renamed from: KQgRr5e_0  reason: collision with other field name */
    public final List<KQgRr5e_0> f151KQgRr5e_0 = new ArrayList();

    /* renamed from: KQgRr5e_0  reason: collision with other field name */
    public final boolean f152KQgRr5e_0;
    public File QxJ9d_1;

    /* renamed from: QxJ9d_1  reason: collision with other field name */
    public String f153QxJ9d_1;

    /* renamed from: QxJ9d_1  reason: collision with other field name */
    public boolean f154QxJ9d_1;

    public PGPF6hQ_2(int i, String str, File file, String str2) {
        this.KQgRr5e_0 = i;
        this.f150KQgRr5e_0 = str;
        this.f149KQgRr5e_0 = file;
        if (IMuAHx_6.KQgRr5e_0.KQgRr5e_0.XnFJ5_9.PGPF6hQ_2.KQgRr5e_0((CharSequence) str2)) {
            this.f148KQgRr5e_0 = new IMuAHx_6.KQgRr5e_0();
            this.f152KQgRr5e_0 = true;
            return;
        }
        this.f148KQgRr5e_0 = new IMuAHx_6.KQgRr5e_0(str2);
        this.f152KQgRr5e_0 = false;
        this.QxJ9d_1 = new File(file, str2);
    }

    public void KQgRr5e_0(boolean z) {
        this.f154QxJ9d_1 = z;
    }

    public String PGPF6hQ_2() {
        return this.f150KQgRr5e_0;
    }

    public int QxJ9d_1() {
        return this.KQgRr5e_0;
    }

    public String toString() {
        return "id[" + this.KQgRr5e_0 + "] url[" + this.f150KQgRr5e_0 + "] etag[" + this.f153QxJ9d_1 + "] taskOnlyProvidedParentPath[" + this.f152KQgRr5e_0 + "] parent path[" + this.f149KQgRr5e_0 + "] filename[" + this.f148KQgRr5e_0.KQgRr5e_0() + "] block(s):" + this.f151KQgRr5e_0.toString();
    }

    public void KQgRr5e_0(KQgRr5e_0 kQgRr5e_0) {
        this.f151KQgRr5e_0.add(kQgRr5e_0);
    }

    /* renamed from: QxJ9d_1  reason: collision with other method in class */
    public boolean m96QxJ9d_1() {
        return this.f152KQgRr5e_0;
    }

    /* renamed from: KQgRr5e_0  reason: collision with other method in class */
    public boolean m93KQgRr5e_0() {
        return this.f154QxJ9d_1;
    }

    /* renamed from: QxJ9d_1  reason: collision with other method in class */
    public long m94QxJ9d_1() {
        Object[] array = this.f151KQgRr5e_0.toArray();
        long j = 0;
        if (array != null) {
            for (Object obj : array) {
                if (obj instanceof KQgRr5e_0) {
                    j += ((KQgRr5e_0) obj).QxJ9d_1();
                }
            }
        }
        return j;
    }

    public KQgRr5e_0 KQgRr5e_0(int i) {
        return this.f151KQgRr5e_0.get(i);
    }

    /* renamed from: KQgRr5e_0  reason: collision with other method in class */
    public void m92KQgRr5e_0() {
        this.f151KQgRr5e_0.clear();
    }

    public int KQgRr5e_0() {
        return this.f151KQgRr5e_0.size();
    }

    public void KQgRr5e_0(String str) {
        this.f153QxJ9d_1 = str;
    }

    /* renamed from: QxJ9d_1  reason: collision with other method in class */
    public String m95QxJ9d_1() {
        return this.f148KQgRr5e_0.KQgRr5e_0();
    }

    /* renamed from: KQgRr5e_0  reason: collision with other method in class */
    public long m87KQgRr5e_0() {
        if (m93KQgRr5e_0()) {
            return m94QxJ9d_1();
        }
        long j = 0;
        Object[] array = this.f151KQgRr5e_0.toArray();
        if (array != null) {
            for (Object obj : array) {
                if (obj instanceof KQgRr5e_0) {
                    j += ((KQgRr5e_0) obj).KQgRr5e_0();
                }
            }
        }
        return j;
    }

    public PGPF6hQ_2(int i, String str, File file, String str2, boolean z) {
        this.KQgRr5e_0 = i;
        this.f150KQgRr5e_0 = str;
        this.f149KQgRr5e_0 = file;
        if (IMuAHx_6.KQgRr5e_0.KQgRr5e_0.XnFJ5_9.PGPF6hQ_2.KQgRr5e_0((CharSequence) str2)) {
            this.f148KQgRr5e_0 = new IMuAHx_6.KQgRr5e_0();
        } else {
            this.f148KQgRr5e_0 = new IMuAHx_6.KQgRr5e_0(str2);
        }
        this.f152KQgRr5e_0 = z;
    }

    /* renamed from: KQgRr5e_0  reason: collision with other method in class */
    public String m91KQgRr5e_0() {
        return this.f153QxJ9d_1;
    }

    /* renamed from: KQgRr5e_0  reason: collision with other method in class */
    public IMuAHx_6.KQgRr5e_0 m88KQgRr5e_0() {
        return this.f148KQgRr5e_0;
    }

    /* renamed from: KQgRr5e_0  reason: collision with other method in class */
    public File m90KQgRr5e_0() {
        String KQgRr5e_0 = this.f148KQgRr5e_0.KQgRr5e_0();
        if (KQgRr5e_0 == null) {
            return null;
        }
        if (this.QxJ9d_1 == null) {
            this.QxJ9d_1 = new File(this.f149KQgRr5e_0, KQgRr5e_0);
        }
        return this.QxJ9d_1;
    }

    /* renamed from: KQgRr5e_0  reason: collision with other method in class */
    public PGPF6hQ_2 m89KQgRr5e_0() {
        PGPF6hQ_2 pGPF6hQ_2 = new PGPF6hQ_2(this.KQgRr5e_0, this.f150KQgRr5e_0, this.f149KQgRr5e_0, this.f148KQgRr5e_0.KQgRr5e_0(), this.f152KQgRr5e_0);
        pGPF6hQ_2.f154QxJ9d_1 = this.f154QxJ9d_1;
        for (KQgRr5e_0 kQgRr5e_0 : this.f151KQgRr5e_0) {
            pGPF6hQ_2.f151KQgRr5e_0.add(kQgRr5e_0.m85KQgRr5e_0());
        }
        return pGPF6hQ_2;
    }

    public void KQgRr5e_0(PGPF6hQ_2 pGPF6hQ_2) {
        this.f151KQgRr5e_0.clear();
        this.f151KQgRr5e_0.addAll(pGPF6hQ_2.f151KQgRr5e_0);
    }

    public boolean KQgRr5e_0(IMuAHx_6.KQgRr5e_0.KQgRr5e_0.PGPF6hQ_2 pGPF6hQ_2) {
        if (this.f149KQgRr5e_0.equals(pGPF6hQ_2.KQgRr5e_0()) && this.f150KQgRr5e_0.equals(pGPF6hQ_2.QxJ9d_1())) {
            String KQgRr5e_0 = pGPF6hQ_2.KQgRr5e_0();
            if (KQgRr5e_0 == null || !KQgRr5e_0.equals(this.f148KQgRr5e_0.KQgRr5e_0())) {
                if (this.f152KQgRr5e_0 && pGPF6hQ_2.QxJ9d_1()) {
                    return KQgRr5e_0 == null || KQgRr5e_0.equals(this.f148KQgRr5e_0.KQgRr5e_0());
                }
                return false;
            }
            return true;
        }
        return false;
    }
}
